==> haskell-irc-core-2.11-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 irc-core
version:              2.11
visibility:           public
id:                   irc-core-2.11-DyRFS9D1sSHBIajD3TPOE2
key:                  irc-core-2.11-DyRFS9D1sSHBIajD3TPOE2
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc

    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  59cfc27bad3285c2282703f1169ac695
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.0.2/site-local/irc-core-2.11
library-dirs:         /usr/lib/ghc-9.0.2/site-local/irc-core-2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.11-DyRFS9D1sSHBIajD3TPOE2
depends:
    attoparsec-0.14.4-IunVluIlg1j8NQqYaVddnF base-4.15.1.0
    base64-bytestring-1.2.1.0-CM0hYSNUcmEXJNyTXmK7o
    bytestring-0.10.12.1 hashable-1.4.3.0-ESEjVh9IF6l3kXlrvIyche
    primitive-0.7.4.0-8SmDsFCxSqgE7BzeiM7pZ4 text-1.2.5.0 time-1.9.3
    vector-0.13.0.0-HZxUYbi5cfB4SV8TkUpCM2

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-irc-core-2.11-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 irc-core
version:              2.11
visibility:           public
id:                   irc-core-2.11-IJAjUg3tHVkAVs0tiiO0St
key:                  irc-core-2.11-IJAjUg3tHVkAVs0tiiO0St
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc

    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  c113bbed09c2ffc912af7a3f525e8aad
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.0.2/site-local/irc-core-2.11
library-dirs:         /usr/lib/ghc-9.0.2/site-local/irc-core-2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.11-IJAjUg3tHVkAVs0tiiO0St
depends:
    attoparsec-0.14.4-3oWeIwuAC9nGIXtuOKUSVb base-4.15.1.0
    base64-bytestring-1.2.1.0-K6aDfGMP3VQ7DntOyJ8qvJ
    bytestring-0.10.12.1 hashable-1.4.3.0-GjMDKgDyLuqLq9SaBPRy7H
    primitive-0.7.4.0-B9Fu4okMgOmJjvJHFt8syV text-1.2.5.0 time-1.9.3
    vector-0.13.1.0-BQe94mmHcwnGaa4dX3J4G3

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
